==> HTML-Menu-TreeView-1.15.tar.gz: HTML-Menu-TreeView-1.15/examples/tree.pl <==
$VAR1 = [
         {
          'text'    => 'Related Sites',
          'subtree' => [
                        {
                         'target'  => '_parent',
                         'text'    => 'Lindnerei.de',
                         'href'    => 'http://lindnerei.de/',
                         'subtree' => [],
                         'id'      => 'a2',
                         'rid'     => 2
                        },
                        {
                         'target'  => '_parent',
                         'href'    => 'http://search.cpan.org/dist/HTML-Menu-TreeView/',
                         'text'    => 'cpan.org',
                         'subtree' => [],
                         'id'      => 'a3',
                         'rid'     => 3
                        },
                        {
                         'target'  => '_parent',
                         'href'    => 'http://lindnerei.svn.sourceforge.net/viewvc/lindnerei/treeview/',
                         'text'    => 'Subversion',
                         'subtree' => [],
                         'id'      => 'a4',
                         'rid'     => 4
                        }
          ],
          'id'  => 'a1',
          'rid' => 1
         },
         {
          'text'    => 'Examples',
          'subtree' => [
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'OO Syntax',
                         'href'    => 'oo.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'ooSource.pl',
                                        'subtree' => [],
                                        'rid'     => 7,
                                        'id'      => 'a7'
                                       }
                         ],
                         'rid' => 6,
                         'id'  => 'a6'
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'fo.pl',
                         'text'    => 'FO Syntax',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'foSource.pl',
                                        'subtree' => [],
                                        'id'      => 'a9',
                                        'rid'     => 9
                                       }
                         ],
                         'id'  => 'a8',
                         'rid' => 8
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'crystal.pl',
                         'text'    => 'Crystal',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'crystalSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a11',
                                        'rid'     => 11
                                       }
                         ],
                         'id'  => 'a10',
                         'rid' => 10
                        },
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'Sort the Treeview',
                         'href'    => 'folderFirst.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'folderSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a13',
                                        'rid'     => 13
                                       }
                         ],
                         'id'  => 'a12',
                         'rid' => 12
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'edit.pl',
                         'text'    => 'Edit',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'editSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a15',
                                        'rid'     => 15
                                       }
                         ],
                         'id'  => 'a14',
                         'rid' => 14
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'select.pl',
                         'text'    => 'Select',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'selectSource.pl',
                                        'subtree' => [],
                                        'rid'     => 17,
                                        'id'      => 'a17'
                                       }
                         ],
                         'rid' => 16,
                         'id'  => 'a16'
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'open.pl',
                         'text'    => 'Closed Folder ',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'openSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a19',
                                        'rid'     => 'a19'
                                       }
                         ],
                         'id'  => 'a18',
                         'rid' => 'a18'
                        },
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'Columns',
                         'href'    => 'columns.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'columnsSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a21',
                                        'rid'     => 21
                                       }
                         ],
                         'id'  => 'a20',
                         'rid' => 20
                        }
          ],
          'id'  => 'a5',
          'rid' => 5
         },
         {
          'text'    => 'Kontakt',
          'href'    => 'mailto:dirk.lindner@gmx.de',
          'subtree' => [],
          'id'      => 'a22',
          'rid'     => 22
         }
];
@TreeView = $VAR1;

==> HTML-Menu-TreeView-1.17.tar.gz: HTML-Menu-TreeView-1.17/examples/tree.pl <==
$VAR1 = [
         {
          'text'    => 'Related Sites',
          'subtree' => [
                        {
                         'target'  => '_parent',
                         'text'    => 'Lindnerei.de',
                         'href'    => 'http://lindnerei.de/',
                         'subtree' => [],
                         'id'      => 'a2',
                         'rid'     => 2
                        },
                        {
                         'target'  => '_parent',
                         'href'    => 'http://search.cpan.org/dist/HTML-Menu-TreeView/',
                         'text'    => 'cpan.org',
                         'subtree' => [],
                         'id'      => 'a3',
                         'rid'     => 3
                        },
                        {
                         'target'  => '_parent',
                         'href'    => 'https://sourceforge.net/p/lindnerei/ajax/HEAD/tree/HTML-Menu-TreeView',
                         'text'    => 'Subversion',
                         'subtree' => [],
                         'id'      => 'a4',
                         'rid'     => 4
                        }
          ],
          'id'  => 'a1',
          'rid' => 1
         },
         {
          'text'    => 'Examples',
          'subtree' => [
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'OO Syntax',
                         'href'    => 'oo.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'ooSource.pl',
                                        'subtree' => [],
                                        'rid'     => 7,
                                        'id'      => 'a7'
                                       }
                         ],
                         'rid' => 6,
                         'id'  => 'a6'
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'fo.pl',
                         'text'    => 'FO Syntax',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'foSource.pl',
                                        'subtree' => [],
                                        'id'      => 'a9',
                                        'rid'     => 9
                                       }
                         ],
                         'id'  => 'a8',
                         'rid' => 8
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'crystal.pl',
                         'text'    => 'Crystal',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'crystalSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a11',
                                        'rid'     => 11
                                       }
                         ],
                         'id'  => 'a10',
                         'rid' => 10
                        },
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'Sort the Treeview',
                         'href'    => 'folderFirst.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'folderSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a13',
                                        'rid'     => 13
                                       }
                         ],
                         'id'  => 'a12',
                         'rid' => 12
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'edit.pl',
                         'text'    => 'Edit',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'editSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a15',
                                        'rid'     => 15
                                       }
                         ],
                         'id'  => 'a14',
                         'rid' => 14
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'select.pl',
                         'text'    => 'Select',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'text'    => 'Source',
                                        'href'    => 'selectSource.pl',
                                        'subtree' => [],
                                        'rid'     => 17,
                                        'id'      => 'a17'
                                       }
                         ],
                         'rid' => 16,
                         'id'  => 'a16'
                        },
                        {
                         'target'  => 'rightFrame',
                         'href'    => 'open.pl',
                         'text'    => 'Closed Folder ',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'openSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a19',
                                        'rid'     => 'a19'
                                       }
                         ],
                         'id'  => 'a18',
                         'rid' => 'a18'
                        },
                        {
                         'target'  => 'rightFrame',
                         'text'    => 'Columns',
                         'href'    => 'columns.pl',
                         'subtree' => [
                                       {
                                        'target'  => 'rightFrame',
                                        'href'    => 'columnsSource.pl',
                                        'text'    => 'Source',
                                        'subtree' => [],
                                        'id'      => 'a21',
                                        'rid'     => 21
                                       }
                         ],
                         'id'  => 'a20',
                         'rid' => 20
                        }
          ],
          'id'  => 'a5',
          'rid' => 5
         },
         {
          'text'    => 'Kontakt',
          'href'    => 'mailto:dirk.lindner@gmx.de',
          'subtree' => [],
          'id'      => 'a22',
          'rid'     => 22
         }
];
@TreeView = $VAR1;
